import os
import zipfile

def create_zip(zip_name, folder_name):
    #check if folder exists
    if os.path.isdir(folder_name):
        print("Folder exists: " + folder_name)
    else:
        return "Folder not exist: " + folder_name
    zipf = zipfile.ZipFile(zip_name, 'w', zipfile.ZIP_DEFLATED)
    for root, dirs, files in os.walk(folder_name):
        for file in files:
            zipf.write(os.path.join(root, file))
    zipf.close()


#To run your unit tests, you can use the unittest command-line interface. 
# From the root directory of your package, you can run the following command: python -m unittest discover
#This will discover and run all of the unit tests in your package. If you want to run a specific test file, you can use the following command:
#python -m unittest tests.test_module_1
#This will run the unit tests in the test_module_1.py file.

import unittest

import robin_sd_upload.module_1 as module_1

class TestModule1(unittest.TestCase):
    def test_bar(self):
        module_1.bar()
        # Add any assertions to verify the output of the bar function.

    def test_variable(self):
        self.assertEqual(module_1.variable, "This variable is defined in module_1.py and can be accessed from any module in the package.")



from setuptools import setup, find_packages

with open("README.md") as file:
    long_description = file.read()

with open("requirements.txt") as file:
    install_requires = file.read().strip().split("\n")

setup(
    name="robin_sd_upload",
    packages=find_packages(),
    install_requires=install_requires,
    entry_points={
    'console_scripts': [
        'robin-sd-upload = robin_sd_upload.__main__:main',
    ],
    },
    version="0.1.42",
    license="MIT",
    description="Package to upload files to the Robin Radar API",
    long_description=long_description,
    long_description_content_type="text/markdown",
    author="Robin Radar Systems",
    author_email="tivadar.kamondy@robinradar.com",
    url="https://bitbucket.org/robin-radar-systems/sd-api-upload-pip-package.git",
    keywords=["python", "robin", "radar", "download", "software", "sd"]
)



import os
import requests
import yaml
import json
from .get_bearer_token import get_bearer_token

def push_software(config, fpath, radarType, version_name):

    print('Getting the bearer token...')
    # check config file type
    if type(config) is not dict:
        return "Config file is not a dictionary"
    else:
        print('config type: ', type(config))
    # check config file
    print('config api_url: ', config['api_url'])

    request_url = config['api_url']

    bearer_token = get_bearer_token(config)

    headers = {
        'Authorization': 'Bearer ' + bearer_token,
    }
    if not bearer_token:
        return "Bearer token is empty"
    else:
        print('bearer_token: ', bearer_token)

    # check if can open file path
    if os.path.isfile(fpath):
        print("ZIP file exists: " + fpath)
    else:
        print("ZIP not exist: " + fpath)
        return "ZIP not exist: " + fpath
        
    files = {
        'file': (fpath, open(fpath, 'rb'))
    }

    values = {
        'destination': json.dumps(radarType),
        'versionName': json.dumps(version_name)
    }
    
    print('Uploading software...')

    response = requests.post(request_url + '/api/softwares/softwarefiles', headers=headers, data=values, files=files)
    return response.json()